# sosw
Serverless Orchestrator of Serverless Workers for AWS - Worker
[![Build Status](https://travis-ci.org/bimpression/sosw.svg?branch=master)](https://travis-ci.org/bimpression/sosw)

Documentation is on the way full speed, for now you can read informative docstrings...